@@ -12,6 +12,7 @@
 #include "dat.h"
 #include "fns.h"
 
+
 void mainloop(int shape_event)
 {
 	Client *c = 0;
@@ -109,9 +110,11 @@ void mainloop(int shape_event)
 		case Expose:
 			expose(&ev.xexpose);
 			break;
-		case SelectionClear:
 		case SelectionNotify:
+			selection (&ev.xselection);
+			break;
 		case SelectionRequest:
+		case SelectionClear:
 		case CirculateRequest:
 		case MotionNotify:
 		case FocusOut:
@@ -129,6 +132,32 @@ void mainloop(int shape_event)
 	}
 }
 
+void selection (XSelectionEvent *e)
+{
+	ScreenInfo *s;
+
+	if (!(s = getbarscreen (e->requestor)))
+		return;
+
+	if (!selapp)
+		return;
+
+	if (e->property != None)
+	{
+		XTextProperty pr;
+
+		if (XGetTextProperty (dpy, e->requestor, &pr, selection_larswm))
+		{
+			strncpy (seltext, (char *) pr.value, sizeof (seltext));
+			XFree (pr.value);
+		}
+	}
+
+	spawn (s, selapp);
+
+	selapp = 0;
+}
+
 void expose(XExposeEvent *e)
 {
 	Client *c;
@@ -349,14 +378,6 @@ void clientmesg(XClientMessageEvent *e)
 		perror("larswm: exec failed");
 		exit(1);
 	}
-	else if (e->message_type == message_larswm)
-	{
-		update_cmd_output ();
-	}
-	else if (e->message_type == flushmessage_larswm)
-	{
-		flush_cmd_output ();
-	}
 	else if (e->message_type == wm_change_state)
 	{
 		c = getclient(e->window, 0);
@@ -396,24 +417,25 @@ void cmap(XColormapEvent *e)
 
 void property(XPropertyEvent *e)
 {
-	Atom a;
-	int delete;
 	Client *c;
 	long msize;
 
-	a = e->atom;
-	delete = (e->state == PropertyDelete);
-	c = getclient(e->window, 0);
+	/* check if text to be displayed on status bar was just changed */
+	if ((e->atom == bartext_larswm) && (e->window == DefaultRootWindow (dpy)))
+	{
+		update_cmd_output ();
+		return;
+	}
 
-	if (c == 0)
+	if (!(c = getclient(e->window, 0)))
 		return;
 
-	switch (a)
+	switch (e->atom)
 	{
 	case XA_WM_ICON_NAME:
 		if (c->iconname != 0)
 			XFree((char*) c->iconname);
-		c->iconname = delete ? 0 : getprop(c->window, a);
+		c->iconname = (e->state == PropertyDelete) ? 0 : getprop(c->window, e->atom);
 		setlabel(c);
 		renamec(c, c->label);
 		break;
@@ -421,7 +443,7 @@ void property(XPropertyEvent *e)
 	case XA_WM_NAME:
 		if (c->name != 0)
 			XFree((char*) c->name);
-		c->name = delete ? 0 : getprop(c->window, a);
+		c->name = (e->state == PropertyDelete) ? 0 : getprop(c->window, e->atom);
 		setlabel(c);
 		renamec(c, c->label);
 		break;
@@ -453,7 +475,7 @@ void property(XPropertyEvent *e)
 		break;
 
 	default:
-		if (a == wm_colormaps)
+		if (e->atom == wm_colormaps)
 		{
 			getcmaps(c);
 
@@ -513,7 +535,7 @@ void enter(XCrossingEvent *e)
 
 	if ((e->mode == NotifyNormal) &&
 	    (s = getscreen (e->window)) &&
-	    (!current || (current->screen != s)))
+	    (current && (current->screen != s)))
 	{
 		revert_same (s);
 
