@@ -31,7 +31,6 @@ void set_defaults (void)
 
 	prefs.border = 2;
 	prefs.tile_pad = 2;
-	prefs.bar = 1;
 
 	for (i = 0; i < MAXSCREENS; i++)
 	{
@@ -84,18 +83,6 @@ void set_defaults (void)
 	prefs.next_window_key = XK_Down;
 	prefs.next_window_mod = DEFAULT_MOD;
 
-	prefs.shrink_left_key = XK_comma;
-	prefs.shrink_left_mod = DEFAULT_MOD;
-
-	prefs.grow_left_key = XK_period;
-	prefs.grow_left_mod = DEFAULT_MOD;
-
-	prefs.max_left_key = XK_End;
-	prefs.max_left_mod = DEFAULT_MOD;
-
-	prefs.restore_left_key = XK_Home;
-	prefs.restore_left_mod = DEFAULT_MOD;
-
 	prefs.raise_notile_key = XK_BackSpace;
 	prefs.raise_notile_mod = DEFAULT_MOD;
 
@@ -126,6 +113,9 @@ void set_defaults (void)
 	prefs.move_southeast_key = XK_KP_Next;
 	prefs.move_southeast_mod = DEFAULT_MOD;
 
+	prefs.toggle_inc_key = XK_KP_Insert;
+	prefs.toggle_inc_mod = MOVE_MOD;
+
 	prefs.move_up_key = XK_KP_Up;
 	prefs.move_up_mod = MOVE_MOD;
 
@@ -174,9 +164,6 @@ void set_defaults (void)
 	prefs.close_key = XK_w;
 	prefs.close_mod = CLOSE_MOD;
 
-	prefs.spawn_key = XK_Return;
-	prefs.spawn_mod = DEFAULT_MOD;
-
 	/* provide defaults for up to 12 virtual desktops */
 	prefs.goto_desktop_key[0] = XK_F1;
 	prefs.goto_desktop_mod[0] = DEFAULT_MOD;
@@ -298,15 +285,7 @@ void dump_prefs (void)
 	printf ("!\n");
 	printf ("! larswm.tile_pad: %d\n", prefs.tile_pad);
 	printf ("!\n");
-	printf ("! Show status bar at the bottom of the screen?\n");
-	printf ("!\n");
-	printf ("! larswm.bar: %s\n", show_bool (prefs.bar));
-	printf ("!\n");
-	printf ("! Show focused window's class and instance on the status bar?\n");
-	printf ("!\n");
-	printf ("! larswm.show_class: %s\n", show_bool (prefs.show_class));
-	printf ("!\n");
-	printf ("! Menu and window border colors:\n");
+	printf ("! Status bar and window border colors:\n");
 	printf ("!\n");
 	if (prefs.fgstr)
 		printf ("! larswm.foreground: %s\n", prefs.fgstr);
@@ -317,57 +296,56 @@ void dump_prefs (void)
 	else
 		printf ("! larswm.background: white\n");
 	printf ("!\n");
-	printf ("! Menu font:\n");
+	printf ("! Status bar font:\n");
 	printf ("!\n");
 	if (prefs.fname)
 		printf ("! larswm.font: %s\n", prefs.fname);
 	else
 		printf ("! larswm.font: fixed\n");
 	printf ("!\n");
-	printf ("! New terminal in main menu launches:\n");
-	printf ("!\n");
-	if (prefs.termprog)
-		printf ("! larswm.terminal: %s\n", prefs.termprog);
-	else
-		printf ("! larswm.terminal: xterm\n");
-	printf ("!\n");
 	printf ("! Number of virtual desktops per physical screen: (1 - %d)\n", MAXDESKTOPS);
 	printf ("!\n");
 	printf ("! larswm.desktops: %d\n", prefs.desktops);
 	printf ("!\n");
 	printf ("! Virtual desktop names:\n");
 	printf ("!\n");
-	printf ("! larswm.*.0.dtname: %s\n", prefs.dtname[0][0]);
-	printf ("! larswm.*.1.dtname: %s\n", prefs.dtname[0][1]);
-	printf ("! larswm.*.2.dtname: %s\n", prefs.dtname[0][2]);
-	printf ("! larswm.*.3.dtname: %s\n", prefs.dtname[0][3]);
+	printf ("! larswm.?.0.dtname: %s\n", prefs.dtname[0][0]);
+	printf ("! larswm.?.1.dtname: %s\n", prefs.dtname[0][1]);
+	printf ("! larswm.?.2.dtname: %s\n", prefs.dtname[0][2]);
+	printf ("! larswm.?.3.dtname: %s\n", prefs.dtname[0][3]);
 	printf ("!\n");
 	printf ("! Resize windows when tiling? (If not, move to and stack in right track)\n");
 	printf ("!\n");
-	printf ("! larswm.*.*.tile_resize: %s\n", show_bool (prefs.tile_resize[0][0]));
+	printf ("! larswm.?.?.tile_resize: %s\n", show_bool (prefs.tile_resize[0][0]));
 	printf ("!\n");
 	printf ("! Width of left track in percent: (5-95)\n");
 	printf ("!\n");
-	printf ("! larswm.*.*.left_track_width: %d\n", prefs.left_track_width[0][0]);
+	printf ("! larswm.?.?.left_track_width: %d\n", prefs.left_track_width[0][0]);
 	printf ("!\n");
 	printf ("! Don't retile on focus change?\n");
 	printf ("!\n");
-	printf ("! larswm.*.*.skip_focus: %s\n", show_bool (prefs.skip_focus[0][0]));
+	printf ("! larswm.?.?.skip_focus: %s\n", show_bool (prefs.skip_focus[0][0]));
 	printf ("!\n");
 	printf ("! When clicking to focus, also pass click on to client?\n");
 	printf ("!\n");
-	printf ("! larswm.*.*.clickthru: %s\n", show_bool (prefs.clickthru[0][0]));
+	printf ("! larswm.?.?.clickthru: %s\n", show_bool (prefs.clickthru[0][0]));
 	printf ("!\n");
 	printf ("! Make all windows on the untiled subdesktop sticky by default?\n");
 	printf ("!\n");
 	printf ("! larswm.sticky_notile: %s\n", show_bool (prefs.sticky_notile));
 	printf ("!\n");
 
-	printf ("! Apps on application menu:\n");
+	printf ("! Application commands for shortcuts:\n");
 	printf ("! Add one line for each application. Must have different numbers between 0 and %d.\n", MAXAPPS - 1);
 	printf ("!\n");
 	printf ("! larswm.application.0: command\n");
 	printf ("!\n");
+	printf ("! Application commands for mouse clicks:\n");
+	printf ("!\n");
+	printf ("! larswm.button1.application: command\n");
+	printf ("! larswm.button2.application: command\n");
+	printf ("! larswm.button3.application: command\n");
+	printf ("!\n");
 
 	printf ("! * In all the class lists, the Instance is optional *\n");
 	printf ("!\n");
@@ -379,7 +357,7 @@ void dump_prefs (void)
 	printf ("! Floating applications: (Will always stay on top of other applications)\n");
 	printf ("! Add one line for each class. Must have different numbers between 0 and %d.\n", MAXFLOATCLASS - 1);
 	printf ("!\n");
-	printf ("! larswm.stickyclass.0: Class~Instance\n");
+	printf ("! larswm.floatclass.0: Class~Instance\n");
 	printf ("!\n");
 	printf ("! Sticky applications: (Will be visible on all virtual desktops)\n");
 	printf ("! Add one line for each class. Must have different numbers between 0 and %d.\n", MAXSTICKYCLASS - 1);
@@ -421,22 +399,6 @@ void dump_prefs (void)
 	printf ("! larswm.next_window_mod: %s\n", show_mod (prefs.next_window_mod));
 	printf ("!\n");
 
-	printf ("! larswm.shrink_left_key: %s\n", XKeysymToString (prefs.shrink_left_key));
-	printf ("! larswm.shrink_left_mod: %s\n", show_mod (prefs.shrink_left_mod));
-	printf ("!\n");
-	printf ("! larswm.grow_left_key: %s\n", XKeysymToString (prefs.grow_left_key));
-	printf ("! larswm.grow_left_mod: %s\n", show_mod (prefs.grow_left_mod));
-	printf ("!\n");
-	printf ("! larswm.max_left_key: %s\n", XKeysymToString (prefs.max_left_key));
-	printf ("! larswm.max_left_mod: %s\n", show_mod (prefs.max_left_mod));
-	printf ("!\n");
-	printf ("! larswm.restore_left_key: %s\n", XKeysymToString (prefs.restore_left_key));
-	printf ("! larswm.restore_left_mod: %s\n", show_mod (prefs.restore_left_mod));
-	printf ("!\n");
-	printf ("! larswm.raise_notile_key: %s\n", XKeysymToString (prefs.raise_notile_key));
-	printf ("! larswm.raise_notile_mod: %s\n", show_mod (prefs.raise_notile_mod));
-	printf ("!\n");
-
 	printf ("! larswm.move_northwest_key: %s\n", XKeysymToString (prefs.move_northwest_key));
 	printf ("! larswm.move_northwest_mod: %s\n", show_mod (prefs.move_northwest_mod));
 	printf ("!\n");
@@ -465,6 +427,10 @@ void dump_prefs (void)
 	printf ("! larswm.move_southeast_mod: %s\n", show_mod (prefs.move_southeast_mod));
 	printf ("!\n");
 
+	printf ("! larswm.toggle_inc_key: %s\n", XKeysymToString (prefs.toggle_inc_key));
+	printf ("! larswm.toggle_inc_mod: %s\n", show_mod (prefs.toggle_inc_mod));
+	printf ("!\n");
+
 	printf ("! larswm.move_up_key: %s\n", XKeysymToString (prefs.move_up_key));
 	printf ("! larswm.move_up_mod: %s\n", show_mod (prefs.move_up_mod));
 	printf ("!\n");
@@ -517,10 +483,6 @@ void dump_prefs (void)
 	printf ("! larswm.close_mod: %s\n", show_mod (prefs.close_mod));
 	printf ("!\n");
 
-	printf ("! larswm.new_terminal_key: %s\n", XKeysymToString (prefs.spawn_key));
-	printf ("! larswm.new_terminal_mod: %s\n", show_mod (prefs.spawn_mod));
-	printf ("!\n");
-
 	printf ("! Desktop shortcuts: Defaults are provided for the first 12 desktops, F1-F12.\n");
 	printf ("! If you have more than 12 desktops, you will have to add key bindings for them\n");
 	printf ("! or just use prev/next desktop to get to where you want.\n");
@@ -636,17 +598,6 @@ void load_prefs (char *filename)
 	if (XrmGetResource (db, "larswm.tile_pad", "Larswm.Tile_pad", &vt, &v))
 		prefs.tile_pad = atoi (v.addr);
 
-	if (XrmGetResource (db, "larswm.bar", "Larswm.Bar", &vt, &v))
-		prefs.bar = get_bool (v.addr);
-
-	if (XrmGetResource (db, "larswm.show_class", "Larswm.Show_class", &vt, &v))
-	{
-		prefs.show_class = get_bool (v.addr);
-
-		if (prefs.show_class)
-			toggle_show_class ();
-	}
-
 	if (XrmGetResource (db, "larswm.sticky_notile", "Larswm.Sticky_notile", &vt, &v))
 		prefs.sticky_notile = get_bool (v.addr);
 
@@ -674,9 +625,6 @@ void load_prefs (char *filename)
 	if (XrmGetResource (db, "larswm.font", "Larswm.Font", &vt, &v))
 		prefs.fname = strdup (v.addr);
 
-	if (XrmGetResource (db, "larswm.terminal", "Larswm.Terminal", &vt, &v))
-		prefs.termprog = strdup (v.addr);
-
 	for (i = 0; i < MAXAPPS; i++)
 	{
 		char res[32], cla[32];
@@ -803,34 +751,6 @@ void load_prefs (char *filename)
 		prefs.next_window_mod = get_mod (v.addr);
 
 
-	if (XrmGetResource (db, "larswm.shrink_left_key", "Larswm.Shrink_left_key", &vt, &v))
-		prefs.shrink_left_key = XStringToKeysym (v.addr);
-
-	if (XrmGetResource (db, "larswm.shrink_left_mod", "Larswm.Shrink_left_mod", &vt, &v))
-		prefs.shrink_left_mod = get_mod (v.addr);
-
-
-	if (XrmGetResource (db, "larswm.grow_left_key", "Larswm.Grow_left_key", &vt, &v))
-		prefs.grow_left_key = XStringToKeysym (v.addr);
-
-	if (XrmGetResource (db, "larswm.grow_left_mod", "Larswm.Grow_left_mod", &vt, &v))
-		prefs.grow_left_mod = get_mod (v.addr);
-
-
-	if (XrmGetResource (db, "larswm.max_left_key", "Larswm.Max_left_key", &vt, &v))
-		prefs.max_left_key = XStringToKeysym (v.addr);
-
-	if (XrmGetResource (db, "larswm.max_left_mod", "Larswm.Max_left_mod", &vt, &v))
-		prefs.max_left_mod = get_mod (v.addr);
-
-
-	if (XrmGetResource (db, "larswm.restore_left_key", "Larswm.Restore_left_key", &vt, &v))
-		prefs.restore_left_key = XStringToKeysym (v.addr);
-
-	if (XrmGetResource (db, "larswm.restore_left_mod", "Larswm.Restore_left_mod", &vt, &v))
-		prefs.restore_left_mod = get_mod (v.addr);
-
-
 	for (i = 0; i < MAXDESKTOPS; i++)
 	{
 		char res[32], cla[32];
@@ -849,6 +769,18 @@ void load_prefs (char *filename)
 	}
 
 
+	for (i = 0; i < MAXBTNAPPS; i++)
+	{
+		char res[32], cla[32];
+
+		sprintf (res, "larswm.button%d.application", i + 1);
+		sprintf (cla, "Larswm.Button%d.Application", i + 1);
+
+		if (XrmGetResource (db, res, cla, &vt, &v))
+			prefs.btnapplication[i] = strdup (v.addr);
+	}
+
+
 	for (i = 0; i < MAXAPPS; i++)
 	{
 		char res[32], cla[32];
@@ -937,6 +869,13 @@ void load_prefs (char *filename)
 		prefs.move_southeast_mod = get_mod (v.addr);
 
 
+	if (XrmGetResource (db, "larswm.toggle_inc_key", "Larswm.Toggle_inc_key", &vt, &v))
+		prefs.toggle_inc_key = XStringToKeysym (v.addr);
+
+	if (XrmGetResource (db, "larswm.toggle_inc_mod", "Larswm.Toggle_inc_mod", &vt, &v))
+		prefs.toggle_inc_mod = get_mod (v.addr);
+
+
 	if (XrmGetResource (db, "larswm.move_up_key", "Larswm.Move_up_key", &vt, &v))
 		prefs.move_up_key = XStringToKeysym (v.addr);
 
@@ -1048,12 +987,5 @@ void load_prefs (char *filename)
 	if (XrmGetResource (db, "larswm.close_mod", "Larswm.Close_mod", &vt, &v))
 		prefs.close_mod = get_mod (v.addr);
 
-
-	if (XrmGetResource (db, "larswm.new_terminal_key", "Larswm.New_terminal_key", &vt, &v))
-		prefs.spawn_key = XStringToKeysym (v.addr);
-
-	if (XrmGetResource (db, "larswm.new_terminal_mod", "Larswm.New_terminal_mod", &vt, &v))
-		prefs.spawn_mod = get_mod (v.addr);
-
 	validate_prefs();
 }
