@@ -36,6 +36,20 @@ static int nrc;
 static int res_track = 0;
 
 
+void getmouse(int *x, int *y, ScreenInfo *s)
+{
+	Window dw1, dw2;
+	int t1, t2;
+	unsigned int t3;
+
+	XQueryPointer(dpy, s->root, &dw1, &dw2, x, y, &t1, &t2, &t3);
+}
+
+void setmouse(int x, int y, ScreenInfo *s)
+{
+	XWarpPointer(dpy, None, s->root, None, None, None, None, x, y);
+}
+
 void rev_clients (void)
 {
 	Client *c;
@@ -210,24 +224,40 @@ void toggle_isfloat (Client *c)
 {
 	if (c)
 		c->isfloat = !c->isfloat;
+
+	update_tbar ();
 }
 
 void toggle_isnotile (Client *c)
 {
 	if (c)
 		c->isnotile = !c->isnotile;
+
+	update_tbar ();
 }
 
 void toggle_istool (Client *c)
 {
 	if (c)
 		c->istool = !c->istool;
+
+	update_tbar ();
 }
 
 void toggle_issticky (Client *c)
 {
 	if (c)
 		c->issticky = !c->issticky;
+
+	update_tbar ();
+}
+
+void toggle_inc (ScreenInfo *s)
+{
+	if (s)
+		s->bigmr[s->desktop] = !s->bigmr[s->desktop];
+
+	update_tbar ();
 }
 
 void toggle_clickthru (ScreenInfo *s)
@@ -567,22 +597,6 @@ void goto_desktop(ScreenInfo *s, int n)
 		s->desktop = n;
 
 	update_desktop(s);
-
-	if (s->notile_raised[s->desktop] && s->notilefocused[s->desktop])
-	{
-		active (s->notilefocused[s->desktop]);
-	}
-	else if (!s->notile_raised[s->desktop] && s->focused[s->desktop])
-	{
-		active (s->focused[s->desktop]);
-	}
-	else
-	{
-		revert_same (s);
-
-		if (!current)
-			revert_window (s);
-	}
 }
 
 void next_desktop(ScreenInfo *s)
@@ -591,22 +605,6 @@ void next_desktop(ScreenInfo *s)
 		s->desktop = 0;
 
 	update_desktop(s);
-
-	if (s->notile_raised[s->desktop] && s->notilefocused[s->desktop])
-	{
-		active (s->notilefocused[s->desktop]);
-	}
-	else if (!s->notile_raised[s->desktop] && s->focused[s->desktop])
-	{
-		active (s->focused[s->desktop]);
-	}
-	else
-	{
-		revert_same (s);
-
-		if (!current)
-			revert_window (s);
-	}
 }
 
 void prev_desktop(ScreenInfo *s)
@@ -615,22 +613,6 @@ void prev_desktop(ScreenInfo *s)
 		s->desktop = prefs.desktops - 1;
 
 	update_desktop(s);
-
-	if (s->notile_raised[s->desktop] && s->notilefocused[s->desktop])
-	{
-		active (s->notilefocused[s->desktop]);
-	}
-	else if (!s->notile_raised[s->desktop] && s->focused[s->desktop])
-	{
-		active (s->focused[s->desktop]);
-	}
-	else
-	{
-		revert_same (s);
-
-		if (!current)
-			revert_window (s);
-	}
 }
 
 void move_hide (Client *c)
@@ -647,31 +629,30 @@ void update_desktop(ScreenInfo *s)
 {
 	Client *c;
 
-	nofocus ();
-
 	for (c = clients; c; c = c->next)
 	{
 		if ((c->screen != s) || (c->parent == c->screen->root) || c->issticky || (c->state != NormalState))
 			continue;
 
 		if (c->desktop == s->desktop)
-		{
 			move_show (c);
-
-			if ((s->notile_raised[s->desktop] && (c == s->notilefocused[s->desktop])) ||
-			    (!s->notile_raised[s->desktop] && (c == s->focused[s->desktop])))
-			{
-				active (c);
-			}
-		}
 		else
-		{
 			move_hide (c);
-		}
+	}
+	
+	if (!s->notile_raised[s->desktop] && s->focused[s->desktop])
+		active (s->focused[s->desktop]);
+	else if (s->notile_raised[s->desktop] && s->notilefocused[s->desktop])
+		active (s->notilefocused[s->desktop]);
+	else
+	{
+		revert_same (s);
+
+		if (!current)
+			revert_window (s);
 	}
 
 	tile_all (s);
-	update_tbar ();
 }
 
 void revert_window (ScreenInfo *s)
@@ -908,7 +889,7 @@ void prev_screen (ScreenInfo *s)
 
 	raise_tbar (s);
 
-	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) / 2, &screens[cur]);
+	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) - 2, &screens[cur]);
 }
 
 void next_screen (ScreenInfo *s)
@@ -925,7 +906,7 @@ void next_screen (ScreenInfo *s)
 
 	raise_tbar (s);
 
-	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) / 2, &screens[cur]);
+	setmouse (DisplayWidth (dpy, cur) / 2, DisplayHeight (dpy, cur) - 2, &screens[cur]);
 }
 
 ScreenInfo *mouse_on_screen (void)
@@ -1120,7 +1101,10 @@ void move_up (Client *c)
 {
 	if (c && c->isnotile)
 	{
-		c->y -= (c->screen->tile_height / 20);
+		if (c->screen->bigmr[c->screen->desktop])
+			c->y -= (c->screen->tile_height / 20);
+		else
+			c->y--;
 
 		if (c->y < 0)
 			c->y = 0;
@@ -1136,7 +1120,10 @@ void move_down (Client *c)
 	{
 		int max_y = c->screen->tile_height - c->dy - BORDER - prefs.tile_pad;
 
-		c->y += (c->screen->tile_height / 20);
+		if (c->screen->bigmr[c->screen->desktop])
+			c->y += (c->screen->tile_height / 20);
+		else
+			c->y++;
 
 		if (c->y > max_y)
 			c->y = max_y;
@@ -1150,7 +1137,10 @@ void move_left (Client *c)
 {
 	if (c && c->isnotile)
 	{
-		c->x -= (DisplayWidth (dpy, c->screen->num) / 20);
+		if (c->screen->bigmr[c->screen->desktop])
+			c->x -= (DisplayWidth (dpy, c->screen->num) / 20);
+		else
+			c->x--;
 
 		if (c->x < 0)
 			c->x = 0;
@@ -1166,7 +1156,10 @@ void move_right (Client *c)
 	{
 		int max_x = DisplayWidth (dpy, c->screen->num) - c->dx - (2 * BORDER);
 
-		c->x += (DisplayWidth (dpy, c->screen->num) / 20);
+		if (c->screen->bigmr[c->screen->desktop])
+			c->x += (DisplayWidth (dpy, c->screen->num) / 20);
+		else
+			c->x++;
 
 		if (c->x > max_x)
 			c->x = max_x;
@@ -1286,10 +1279,30 @@ void grow (Client *c, int dimension, int m)
 {
 	int h, w, dh, dw, x, y;
 	int odx, ody, want_w, want_h;
+	int ddx, ddy;
 
-	if (!c || !c->isnotile || !dimension)
+	if (!c || !dimension)
 		return;
 
+	if (!c->isnotile)
+	{
+		if (dimension == DIM_HORIZ)
+		{
+			if (m > 0)
+				grow_left (c->screen);
+			else
+				shrink_left (c->screen);
+		}
+		else if (dimension == DIM_VERT)
+		{
+			if (m > 0)
+				max_left (c->screen);
+			else
+				restore_left (c->screen);
+		}
+		return;
+	}
+
 	x = c->x;
 	y = c->y;
 
@@ -1299,10 +1312,26 @@ void grow (Client *c, int dimension, int m)
 	dw = DisplayWidth (dpy, c->screen->num) - (2 * BORDER);
 	dh = c->screen->tile_height - (2 * BORDER);
 
+	if (c->screen->bigmr[c->screen->desktop])
+	{
+		ddx = (dw / 20);
+		ddy = (dh / 20);
+	}
+	else if (c->size.flags & PResizeInc)
+	{
+		ddx = c->size.width_inc;
+		ddy = c->size.height_inc;
+	}
+	else
+	{
+		ddx = 2;
+		ddy = 2;
+	}
+
 	if (dimension & DIM_HORIZ)
 	{
-		x -= ((dw / 40) - (2 * BORDER) - 2) * m;
-		w += (dh / 20) * m;
+		x -= (ddx / 2) * m;
+		w += ddx * m;
 
 		if ((x + w) > dw)
 			x = dw - w;
@@ -1319,8 +1348,8 @@ void grow (Client *c, int dimension, int m)
 
 	if (dimension & DIM_VERT)
 	{
-		y -= ((dh / 40) + (2 * BORDER) + 2) * m;
-		h += (dw / 20) * m;
+		y -= (ddy / 2) * m;
+		h += ddy * m;
 
 		if ((y + h) > dh)
 			y = dh - h;
